@@ -24,7 +24,7 @@ import numpy as np
 
 __all__ = ('VLE', 'VLECache')
 
-# @njit#(cache=True)
+# @njit(cache=True)
 def xV_iter(xV, Psat_over_P_phi, T, z, z_light, z_heavy, f_gamma, gamma_args, f_pcf, pcf_args):
     xV = xV.copy()
     x = xV[:-1]
@@ -32,12 +32,44 @@ def xV_iter(xV, Psat_over_P_phi, T, z, z_light, z_heavy, f_gamma, gamma_args, f_
     x[x < 0.] = 0.
     x = fn.normalize(x)
     Ks = Psat_over_P_phi * f_gamma(x, T, *gamma_args) * f_pcf(x, T, *pcf_args)
-    xV[-1] = V = binary.phase_fraction(z, Ks, V,
+    V = binary.solve_phase_fraction_Rashford_Rice(z, Ks, V,
                                        z_light,
                                        z_heavy)
+    if V < 0.: V = 0.
+    elif V > 1.: V = 1.
+    xV[-1] = V
+    xV[:-1] = z/(1. + V * (Ks - 1.))
+    return xV
+
+# @njit(cache=True)    
+def xV_iter_2n(xV, Psat_over_P_phi, T, z, f_gamma, gamma_args, f_pcf, pcf_args):
+    xV = xV.copy()
+    x = xV[:-1]
+    V = xV[-1]
+    x[x < 0.] = 0.
+    x = fn.normalize(x)
+    Ks = Psat_over_P_phi * f_gamma(x, T, *gamma_args) * f_pcf(x, T, *pcf_args)
+    V = binary.compute_phase_fraction_2N(z, Ks)
+    if V < 0.: V = 0.
+    elif V > 1.: V = 1.
+    xV[-1] = V
+    xV[:-1] = z/(1. + V * (Ks - 1.))
+    return xV
+
+# @njit(cache=True)
+def xV_iter_3n(xV, Psat_over_P_phi, T, z, f_gamma, gamma_args, f_pcf, pcf_args):
+    xV = xV.copy()
+    x = xV[:-1]
+    V = xV[-1]
+    x[x < 0.] = 0.
+    x = fn.normalize(x)
+    Ks = Psat_over_P_phi * f_gamma(x, T, *gamma_args) * f_pcf(x, T, *pcf_args)
+    V = binary.compute_phase_fraction_3N(z, Ks)
+    if V < 0.: V = 0.
+    elif V > 1.: V = 1.
+    xV[-1] = V
     xV[:-1] = z/(1. + V * (Ks - 1.))
     return xV
-    
 
 class VLE(Equilibrium, phases='lg'):
     """
@@ -755,18 +787,26 @@ class VLE(Equilibrium, phases='lg'):
         H_hat = H/F_mass
         H_hat_bubble = self._H_hat_err_at_T(T_bubble, 0.)
         if H_hat_bubble > H_hat:
-            vapor_mol[index] = 0
-            liquid_mol[index] = mol
-            self._T = thermal_condition.T = self.mixture.xsolve_T(
-                self._phase_data, H, T_bubble, P
+            def f(V):
+                vapor_mol[index] = V * mol
+                liquid_mol[index] = (1 - V) * mol
+                return self.mixture.xH(self._phase_data, T_bubble, P)/self._F_mass - H_hat
+            self._T = thermal_condition.T = T_bubble
+            flx.IQ_interpolation(f,
+                0, 1., f(0), f(1.), V, self.V_tol, self.H_hat_tol, 
+                checkiter=False, checkbounds=False
             )
             return
         H_hat_dew = self._H_hat_err_at_T(T_dew, 0.)
         if H_hat_dew < H_hat:
-            vapor_mol[index] = mol
-            liquid_mol[index] = 0.
-            self._T = thermal_condition.T = self.mixture.xsolve_T(
-                self._phase_data, H, T_dew, P
+            def f(V):
+                vapor_mol[index] = V * mol
+                liquid_mol[index] = (1 - V) * mol
+                return self.mixture.xH(self._phase_data, T_dew, P)/self._F_mass - H_hat
+            self._T = thermal_condition.T = T_dew
+            flx.IQ_interpolation(f,
+                0, 1., f(0), f(1.), V, self.V_tol, self.H_hat_tol, 
+                checkiter=False, checkbounds=False
             )
             return
         else:
@@ -824,10 +864,18 @@ class VLE(Equilibrium, phases='lg'):
         pcf = self._pcf
         x = self._x
         Psat_over_P_phi = Psats_over_P / phi
-        f = xV_iter
+        N = self._N
         z = self._z
-        args = (Psat_over_P_phi, T, z, self._z_light, 
-                self._z_heavy, gamma.f, gamma.args, pcf.f, pcf.args)
+        if N > 3 or self._z_light or self._z_heavy:
+            f = xV_iter
+            args = (Psat_over_P_phi, T, z, self._z_light, 
+                    self._z_heavy, gamma.f, gamma.args, pcf.f, pcf.args)
+        elif N == 2:
+            f = xV_iter_2n
+            args = (Psat_over_P_phi, T, z, gamma.f, gamma.args, pcf.f, pcf.args)
+        elif N == 3:
+            f = xV_iter_3n
+            args = (Psat_over_P_phi, T, z, gamma.f, gamma.args, pcf.f, pcf.args)
         xV = np.zeros(x.size + 1)
         xV[:-1] = x
         xV[-1] = self._V
