@@ -15,51 +15,51 @@ from math import log
     
 @functor(var='H')
 def Enthalpy(T, Cn, T_ref, H_ref):
-    return H_ref + Cn.integrate_by_T(T_ref, T)
+    return H_ref + Cn.T_dependent_property_integral(T_ref, T)
 
 @functor(var='S')
 def Entropy(T, Cn, T_ref, S0):
-    return S0 + Cn.integrate_by_T_over_T(T_ref, T)
+    return S0 + Cn.T_dependent_property_integral_over_T(T_ref, T)
 
 @functor(var='H.l')
 def Liquid_Enthalpy_Ref_Liquid(T, Cn_l, T_ref, H_ref):
     """Enthapy (kJ/kmol) disregarding pressure and assuming the specified phase."""
-    return H_ref + Cn_l.integrate_by_T(T_ref, T)
+    return H_ref + Cn_l.T_dependent_property_integral(T_ref, T)
 
 @functor(var='H.l')
 def Liquid_Enthalpy_Ref_Gas(T, Cn_l, H_int_Tb_to_T_ref_g, Hvap_Tb, Tb, H_ref):
-    return H_ref - H_int_Tb_to_T_ref_g - Hvap_Tb + Cn_l.integrate_by_T(Tb, T)
+    return H_ref - H_int_Tb_to_T_ref_g - Hvap_Tb + Cn_l.T_dependent_property_integral(Tb, T)
     
 @functor(var='H.l')
 def Liquid_Enthalpy_Ref_Solid(T, Cn_l, H_int_T_ref_to_Tm_s, Hfus, Tm, H_ref):
-    return H_ref + H_int_T_ref_to_Tm_s + Hfus + Cn_l.integrate_by_T(Tm, T)
+    return H_ref + H_int_T_ref_to_Tm_s + Hfus + Cn_l.T_dependent_property_integral(Tm, T)
     
 @functor(var='H.s')
 def Solid_Enthalpy_Ref_Solid(T, Cn_s, T_ref, H_ref):
-    return H_ref + Cn_s.integrate_by_T(T_ref, T)
+    return H_ref + Cn_s.T_dependent_property_integral(T_ref, T)
 
 @functor(var='H.s')
 def Solid_Enthalpy_Ref_Liquid(T, Cn_s, H_int_Tm_to_T_ref_l, Hfus, Tm, H_ref):
-    return H_ref - H_int_Tm_to_T_ref_l - Hfus + Cn_s.integrate_by_T(Tm, T)
+    return H_ref - H_int_Tm_to_T_ref_l - Hfus + Cn_s.T_dependent_property_integral(Tm, T)
 
 @functor(var='H.s')
 def Solid_Enthalpy_Ref_Gas(T, Cn_s, H_int_Tb_to_T_ref_g, Hvap_Tb,
                            H_int_Tm_to_Tb_l, Hfus, Tm, H_ref):
-    return H_ref - H_int_Tb_to_T_ref_g - Hvap_Tb - H_int_Tm_to_Tb_l - Hfus + Cn_s.integrate_by_T(Tm, T)
+    return H_ref - H_int_Tb_to_T_ref_g - Hvap_Tb - H_int_Tm_to_Tb_l - Hfus + Cn_s.T_dependent_property_integral(Tm, T)
     
 @functor(var='H.g')
 def Gas_Enthalpy_Ref_Gas(T, Cn_g, T_ref, H_ref):
-    return H_ref + Cn_g.integrate_by_T(T_ref, T)
+    return H_ref + Cn_g.T_dependent_property_integral(T_ref, T)
 
 @functor(var='H.g')
 def Gas_Enthalpy_Ref_Liquid(T, Cn_g, H_int_T_ref_to_Tb_l, Hvap_Tb, 
                             Tb, H_ref):
-    return H_ref + H_int_T_ref_to_Tb_l + Hvap_Tb + Cn_g.integrate_by_T(Tb, T)
+    return H_ref + H_int_T_ref_to_Tb_l + Hvap_Tb + Cn_g.T_dependent_property_integral(Tb, T)
 
 @functor(var='H.g')
 def Gas_Enthalpy_Ref_Solid(T, Cn_g, H_int_T_ref_to_Tm_s, Hfus,
                            H_int_Tm_to_Tb_l, Hvap_Tb, Tb, H_ref):
-    return H_ref + H_int_T_ref_to_Tm_s + Hfus + H_int_Tm_to_Tb_l + Hvap_Tb + Cn_g.integrate_by_T(Tb, T)
+    return H_ref + H_int_T_ref_to_Tm_s + Hfus + H_int_Tm_to_Tb_l + Hvap_Tb + Cn_g.T_dependent_property_integral(Tb, T)
 
 
 EnthalpyRefLiquid = PhaseTFunctorBuilder('H',
@@ -80,42 +80,42 @@ EnthalpyRefGas = PhaseTFunctorBuilder('H',
 @functor(var='S.l')
 def Liquid_Entropy_Ref_Liquid(T, Cn_l, T_ref, S0):
     """Enthapy (kJ/kmol) disregarding pressure and assuming the specified phase."""
-    return S0 + Cn_l.integrate_by_T_over_T(T_ref, T)
+    return S0 + Cn_l.T_dependent_property_integral_over_T(T_ref, T)
 
 @functor(var='S.l')
 def Liquid_Entropy_Ref_Gas(T, Cn_l, S_int_Tb_to_T_ref_g, Svap_Tb, Tb, S0):
-    return S0 - S_int_Tb_to_T_ref_g - Svap_Tb + Cn_l.integrate_by_T_over_T(Tb, T)
+    return S0 - S_int_Tb_to_T_ref_g - Svap_Tb + Cn_l.T_dependent_property_integral_over_T(Tb, T)
     
 @functor(var='S.l')
 def Liquid_Entropy_Ref_Solid(T, Cn_l, S_int_T_ref_to_Tm_s, Sfus, Tm, S0):
-    return S0 + S_int_T_ref_to_Tm_s + Sfus + Cn_l.integrate_by_T_over_T(Tm, T)
+    return S0 + S_int_T_ref_to_Tm_s + Sfus + Cn_l.T_dependent_property_integral_over_T(Tm, T)
     
 @functor(var='S.s')
 def Solid_Entropy_Ref_Solid(T, Cn_s, T_ref, S0):
-    return S0 + Cn_s.integrate_by_T_over_T(T_ref, T)
+    return S0 + Cn_s.T_dependent_property_integral_over_T(T_ref, T)
 
 @functor(var='S.s')
 def Solid_Entropy_Ref_Liquid(T, Cn_s, S_int_Tm_to_T_ref_l, Sfus, Tm, S0):
-    return S0 - S_int_Tm_to_T_ref_l - Sfus + Cn_s.integrate_by_T_over_T(Tm, T)
+    return S0 - S_int_Tm_to_T_ref_l - Sfus + Cn_s.T_dependent_property_integral_over_T(Tm, T)
 
 @functor(var='S.s')
 def Solid_Entropy_Ref_Gas(T, Cn_s, S_int_Tb_to_T_ref_g, Svap_Tb, 
                           S_int_Tm_to_Tb_l, Sfus, Tm, S0):
-    return S0 - S_int_Tb_to_T_ref_g - Svap_Tb - S_int_Tm_to_Tb_l - Sfus + Cn_s.integrate_by_T_over_T(Tm, T)
+    return S0 - S_int_Tb_to_T_ref_g - Svap_Tb - S_int_Tm_to_Tb_l - Sfus + Cn_s.T_dependent_property_integral_over_T(Tm, T)
     
 @functor(var='S.g')
 def Gas_Entropy_Ref_Gas(T, P, Cn_g, T_ref, P_ref, S0):
-    return S0 + Cn_g.integrate_by_T_over_T(T_ref, T) - R*log(P/P_ref)
+    return S0 + Cn_g.T_dependent_property_integral_over_T(T_ref, T) - R*log(P/P_ref)
 
 @functor(var='S.g')
 def Gas_Entropy_Ref_Liquid(T, P, Cn_g, S_int_T_ref_to_Tb_l, Svap_Tb,
                            Tb, P_ref, S0):
-    return S0 + S_int_T_ref_to_Tb_l + Svap_Tb + Cn_g.integrate_by_T_over_T(Tb, T) - R*log(P/P_ref)
+    return S0 + S_int_T_ref_to_Tb_l + Svap_Tb + Cn_g.T_dependent_property_integral_over_T(Tb, T) - R*log(P/P_ref)
 
 @functor(var='S.g')
 def Gas_Entropy_Ref_Solid(T, P, Cn_g, S_int_T_ref_to_Tm_s, Sfus,
                           S_int_Tm_to_Tb_l, Svap_Tb, Tb, P_ref, S0):
-    return S0 + S_int_T_ref_to_Tm_s + Sfus + S_int_Tm_to_Tb_l + Svap_Tb + Cn_g.integrate_by_T_over_T(Tb, T) - R*log(P/P_ref)
+    return S0 + S_int_T_ref_to_Tm_s + Sfus + S_int_Tm_to_Tb_l + Svap_Tb + Cn_g.T_dependent_property_integral_over_T(Tb, T) - R*log(P/P_ref)
 
 
 EntropyRefLiquid = PhaseTPFunctorBuilder('S',
@@ -139,9 +139,9 @@ def Excess_Liquid_Enthalpy_Ref_Liquid(T, P):
 
 @functor(var='H.l')
 def Excess_Liquid_Enthalpy_Ref_Gas(T, P, eos, H_dep_Tb_Pb_g,
-                                   H_dep_Tb_P_ref_g, eos_1atm):
+                                   H_dep_Tb_P_ref_g):
     return (H_dep_Tb_Pb_g - H_dep_Tb_P_ref_g
-            + eos.to_TP(T, P).H_dep_l - eos_1atm.H_dep_l)
+            + eos.to_TP(T, P).H_dep_l - eos.to_TP(T, 101325).H_dep_l)
     
 @functor(var='H.l')
 def Excess_Liquid_Enthalpy_Ref_Solid(T, P):
@@ -193,9 +193,9 @@ def Excess_Liquid_Entropy_Ref_Liquid(T, P):
 
 @functor(var='S.l')
 def Excess_Liquid_Entropy_Ref_Gas(T, P, eos, S_dep_Tb_Pb_g,
-                                  S_dep_Tb_P_ref_g, eos_1atm):
+                                  S_dep_Tb_P_ref_g):
     return (S_dep_Tb_Pb_g - S_dep_Tb_P_ref_g
-            + eos.to_TP(T, P).S_dep_l - eos_1atm.S_dep_l)
+            + eos.to_TP(T, P).S_dep_l - eos.to_TP(T, 101325).S_dep_l)
     
 @functor(var='S.l')
 def Excess_Liquid_Entropy_Ref_Solid(T, P):
